/*
 * Copyright 2004 Carlos Sanchez.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.oness.common.model.vo;

import net.sf.oness.common.all.BaseObject;
import net.sf.oness.common.model.temporal.DateRange;

/**
 * Basic implementation of AuditableValue
 * 
 * @author Carlos Sanchez
 * @version $Revision: 1.8 $
 */
public abstract class AbstractValue extends BaseObject implements
        AuditableValue {

    private DateRange transactionTime = DateRange.startingOn(null);

    private String notes;

    protected Long id;

    protected Long code;

    /**
     * @hibernate.id generator-class="native"
     * 
     * @return
     */
    public Long getId() {
        return this.id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @param code
     *            The code to set.
     */
    public void setCode(Long code) {
        this.code = code;
    }

    /**
     * @hibernate.property not-null="false"
     * 
     * @return Returns the code.
     */
    public Long getCode() {
        return code;
    }

    public void setTransactionTime(DateRange transactionTime) {
        this.transactionTime = transactionTime;
    }

    /**
     * @hibernate.property type="net.sf.oness.common.model.temporal.hibernate.DateRangeType"
     * @hibernate.column name="start" not-null="true"
     * @hibernate.column name="end"
     * 
     * @see net.sf.oness.common.model.vo.AuditableValue#getTransactionTime()
     */
    public DateRange getTransactionTime() {
        return transactionTime;
    }

    /**
     * Notes for this object
     * 
     * @hibernate.property
     * 
     * @return
     */
    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    /**
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object o) {
        return ExceptionSafeEqualsBuilder.reflectionEquals(this, o);
    }

    /**
     * @see java.lang.Object#hashCode()
     */
    public int hashCode() {
        return ExceptionSafeHashCodeBuilder.reflectionHashCode(this);
    }

    /**
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return new ExceptionSafeReflectionToStringBuilder(this).toString();
    }

}