/*
 * Copyright 2004 Carlos Sanchez.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.oness.common.model.vo;

import net.sf.oness.common.model.temporal.DateRange;

/**
 * Interface to be implemented by value objects that allow data auditing
 * 
 * @author Carlos Sanchez
 * @version $Revision: 1.3 $
 */
public interface AuditableValue {

    /**
     * The identifier of each version of each object
     * 
     * @return
     */
    public Long getId();

    /**
     * 
     * @param id
     */
    public void setId(Long id);

    /**
     * @param code
     *            The code to set.
     */
    public void setCode(Long code);

    /**
     * The code that identifies all version of the same object
     * 
     * @return Returns the code.
     */
    public Long getCode();

    /**
     * 
     * @param transactionTime
     */
    public void setTransactionTime(DateRange transactionTime);

    /**
     * Range of time when the data is entered into the system
     * 
     * @return
     */
    public DateRange getTransactionTime();

    /**
     * @see java.lang.Object#clone()
     */
    public Object clone();

}